@@ -61,7 +61,7 @@ predvarplot.mif <- function (object, pars, type = 'l', mean = FALSE, ...) {
   npv <- pred.var(object,pars)/(object@random.walk.sd[pars]^2)
   if (!is.null(dim(npv))) npv <- t(npv)
   if (mean && !is.null(dim(npv)))
-    npv <- apply(npv,1,mean)
+    npv <- rowMeans(npv)
   if (!is.null(dim(npv))) {
     matplot(time(object),npv,type=type,ylab='prediction variance',xlab='time',...)
     legend(x='topright',legend=pars,col=1:length(pars),lty=1:length(pars),bty='n')
